﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;

namespace TemplateColumnLayout
{
    public class Customer : ObservableModel
    {
        //public static string ContactImagePath = ImageFilePathProvider.GetImageLocalPath() + "People/";

        private string _customerId;
        public string CustomerID
        {
            get
            {
                return _customerId;
            }
            set
            {
                if (_customerId != value)
                {
                    _customerId = value;
                    this.NotifyPropertyChanged("CustomerID");
                }
            }
        }

        private string _company;
        public string Company
        {
            get
            {
                return _company;
            }
            set
            {
                if (_company != value)
                {
                    _company = value;
                    this.NotifyPropertyChanged("Company");
                }
            }
        }

        private string _contactName;
        public string ContactName
        {
            get
            {
                return _contactName;
            }
            set
            {
                if (_contactName != value)
                {
                    _contactName = value;
                    this.NotifyPropertyChanged("ContactName");
                }
            }
        }

        public string ContactNameCompanyPhone
        {
            get
            {
                return string.Format("{0}: {1} / {2}", _company, _contactName, _phone);
            }
        }

        private string _contactTitle;
        public string ContactTitle
        {
            get
            {
                return _contactTitle;
            }
            set
            {
                if (_contactTitle != value)
                {
                    _contactTitle = value;
                    this.NotifyPropertyChanged("ContactTitle");
                }
            }
        }

        private string _contactEmail;
        public string ContactEmail
        {
            get
            {
                return _contactEmail;
            }
            set
            {
                if (_contactEmail != value)
                {
                    _contactEmail = value;
                    this.NotifyPropertyChanged("ContactEmail");
                }
            }
        }

        private string _addressOne;
        public string AddressOne
        {
            get
            {
                return _addressOne;
            }
            set
            {
                if (_addressOne != value)
                {
                    _addressOne = value;
                    this.NotifyPropertyChanged("AddressOne");
                }
            }
        }

        private string _addressTwo;
        public string AddressTwo
        {
            get
            {
                return _addressTwo;
            }
            set
            {
                if (_addressTwo != value)
                {
                    _addressTwo = value;
                    this.NotifyPropertyChanged("AddressTwo");
                }
            }
        }

        private string _city;
        public string City
        {
            get
            {
                return _city;
            }
            set
            {
                if (_city != value)
                {
                    _city = value;
                    this.NotifyPropertyChanged("City");
                }
            }
        }

        private string _region;
        public string Region
        {
            get
            {
                return _region;
            }
            set
            {
                if (_region != value)
                {
                    _region = value;
                    this.NotifyPropertyChanged("Region");
                }
            }
        }

        public string FormatedCityState
        {
            get
            {
                return _city + ", " + _region + " " + _postalCode;
            }
        }


        private string _country;
        public string Country
        {
            get
            {
                return _country;
            }
            set
            {
                if (_country != value)
                {
                    _country = value;
                    this.NotifyPropertyChanged("Country");
                }
            }
        }

        private string _postalCode;
        public string PostalCode
        {
            get
            {
                return _postalCode;
            }
            set
            {
                if (_postalCode != value)
                {
                    _postalCode = value;
                    this.NotifyPropertyChanged("PostalCode");
                }
            }
        }

        private string _phone;
        public string Phone
        {
            get
            {
                return _phone;
            }
            set
            {
                if (_phone != value)
                {
                    _phone = value;
                    this.NotifyPropertyChanged("Phone");
                }
            }
        }


        private string _fax;
        public string Fax
        {
            get
            {
                return _fax;
            }
            set
            {
                if (_fax != value)
                {
                    _fax = value;
                    this.NotifyPropertyChanged("Fax");
                }
            }
        }

        private string _imageResourcePath;
        public string ImageResourcePath
        {
            get
            {
                return _imageResourcePath;
            }
            set
            {
                if (_imageResourcePath != value)
                {
                    _imageResourcePath = value;
                    this.NotifyPropertyChanged("ImageResourcePath");
                }
            }
        }
        private ObservableCollection<Order> _orders;

        public ObservableCollection<Order> Orders
        {
            get
            {
                return _orders;
            }

            set
            {
                if (_orders != value)
                {
                    _orders = value;
                    this.NotifyPropertyChanged("Orders");

                }
            }
        }



    }

    public class Order : ObservableModel
    {
        private int orderId;
        private string shipName;
        private decimal freight;
        private string shipAdress;
        private DateTime orderDate;

        public int OrderId
        {
            get
            {
                return orderId;
            }

            set
            {
                if (orderId != value)
                {
                    orderId = value;
                    NotifyPropertyChanged();
                }
            }
        }

        public string ShipName
        {
            get
            {
                return shipName;
            }

            set
            {
                if (shipName != value)
                {
                    shipName = value;
                    NotifyPropertyChanged();
                }
            }
        }

        public decimal Freight
        {
            get
            {
                return freight;
            }

            set
            {
                if (freight != value)
                {
                    freight = value;
                    NotifyPropertyChanged();
                }
            }
        }

        public string ShipAdress
        {
            get
            {
                return shipAdress;
            }

            set
            {
                if (shipAdress != value)
                {
                    shipAdress = value;
                    NotifyPropertyChanged();
                }
            }
        }

        public DateTime OrderDate
        {
            get
            {
                return orderDate;
            }

            set
            {
                if (orderDate != value)
                {
                    orderDate = value;
                    NotifyPropertyChanged();
                }
            }
        }
    }

    public abstract class ObservableModel : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        protected void NotifyPropertyChanged([CallerMemberName] String propertyName = "")
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}


